// bumpmapping.frag

varying vec3 lightVector;
varying vec3 camera;

uniform sampler2D diffuse;
uniform sampler2D normalMap;

void main()
{
	
	vec4 matDiffuse = texture2D(diffuse, gl_TexCoord[0].st);
	vec3 normal = texture2D(normalMap, gl_TexCoord[0].st).xyz * 2.0 - 1.0;

	vec4 ambient = vec4(0.0);
	vec4 diffuse = vec4(0.0);
	vec4 specular = vec4(0.0);

	float dist = length(lightVector);
	
	vec3 L = normalize(lightVector);
	vec3 N = normalize(normal);
	vec3 C = normalize(camera);

	float diffuseFactor = max(0.0, dot(N, L));
	float specularFactor = 0.0;

	if(diffuseFactor != 0.0) {
		vec3 halfVector = normalize(C + L);
		specularFactor = pow(dot(halfVector, N), gl_FrontMaterial.shininess);
	}	
	
	ambient = matDiffuse * gl_LightSource[0].ambient;
	diffuse = matDiffuse * gl_LightSource[0].diffuse * diffuseFactor;
	specular = gl_LightSource[0].specular * specularFactor;
	
	gl_FragColor = ambient + diffuse + specular;

}
